"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var WebSocketSession_1 = require("./WebSocketSession");
var Utils_1 = require("./Utils");
var WebSocketWrapper_1 = require("./WebSocketWrapper");
var WebSocketConnection = /** @class */ (function () {
    function WebSocketConnection(webSocket, webSocketBridgeCommunication) {
        this.webSocket = webSocket;
        this.webSocketBridgeCommunication = webSocketBridgeCommunication;
        this.sessions = new Array();
        this.closedByUser = false;
    }
    WebSocketConnection.prototype.getXcApiList = function () {
        return this.webSocketBridgeCommunication.getXcApiList();
    };
    WebSocketConnection.prototype.getCompositionModel = function (xcApiName) {
        return this.webSocketBridgeCommunication.getCompositionModel(xcApiName);
    };
    WebSocketConnection.prototype.createSession = function (apiName) {
        return this.initConnection(apiName);
    };
    WebSocketConnection.prototype.createAuthenticatedSession = function (apiName, sessionData) {
        return this.initConnection(apiName, sessionData);
    };
    WebSocketConnection.prototype.dispose = function () {
        var _this = this;
        this.sessions.forEach(function (session) {
            Utils_1.Utils.removeElementFromArray(_this.sessions, session);
        }, this);
        this.closedByUser = true;
        this.webSocket.close();
    };
    WebSocketConnection.prototype.initConnection = function (apiName, sessionData) {
        var _this = this;
        return this.webSocketBridgeCommunication.getXcApiConfiguration(apiName)
            .then(function (configuration) {
            var session = new WebSocketSession_1.WebSocketSession(new WebSocketWrapper_1.WebSocketWrapper(_this.webSocket), configuration, sessionData);
            _this.sessions.push(session);
            return session;
        });
    };
    return WebSocketConnection;
}());
exports.WebSocketConnection = WebSocketConnection;
//# sourceMappingURL=WebSocketConnection.js.map