"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Utils_1 = require("../communication/Utils");
var uuid = require("uuid/v4");
var xcWebSocketBridgeConfiguration_1 = require("../configuration/xcWebSocketBridgeConfiguration");
var PrivateTopics = /** @class */ (function () {
    function PrivateTopics(subscriber) {
        this.subscriber = subscriber;
        this.defaultPublisherTopic = uuid();
        this.subscriberTopics = [];
        this.addSubscriberTopic(this.defaultPublisherTopic);
    }
    PrivateTopics.prototype.setDefaultPublisherTopic = function (newDefaultPublisherTopic) {
        if (newDefaultPublisherTopic) {
            this.addSubscriberTopic(newDefaultPublisherTopic);
            this.removeSubscriberTopic(this.defaultPublisherTopic);
            this.defaultPublisherTopic = newDefaultPublisherTopic;
        }
    };
    PrivateTopics.prototype.getDefaultPublisherTopic = function () {
        return this.defaultPublisherTopic;
    };
    PrivateTopics.prototype.addSubscriberTopic = function (privateTopic) {
        if (privateTopic && this.subscriberTopics.indexOf(privateTopic) === -1) {
            this.subscriber.sendSubscribeRequestToTopic(privateTopic, xcWebSocketBridgeConfiguration_1.Kinds.Private);
            this.subscriberTopics.push(privateTopic);
        }
    };
    PrivateTopics.prototype.removeSubscriberTopic = function (privateTopic) {
        if (privateTopic && this.subscriberTopics.indexOf(privateTopic) !== -1) {
            this.subscriber.sendUnsubscribeRequestToTopic(privateTopic, xcWebSocketBridgeConfiguration_1.Kinds.Private);
            Utils_1.Utils.removeElementFromArray(this.subscriberTopics, privateTopic);
        }
    };
    PrivateTopics.prototype.getSubscriberTopics = function () {
        return this.subscriberTopics;
    };
    PrivateTopics.prototype.dispose = function () {
        var _this = this;
        this.subscriberTopics.forEach(function (subscriberTopic) {
            _this.subscriber.sendUnsubscribeRequestToTopic(subscriberTopic, xcWebSocketBridgeConfiguration_1.Kinds.Private);
        }, this);
    };
    return PrivateTopics;
}());
exports.PrivateTopics = PrivateTopics;
//# sourceMappingURL=PrivateTopics.js.map